
/**
* ...
* @author Dani Llops
* @version 1.0
* @description Clase para manipular y obtener valores de color 
* en formatos legibles.
* Es una modificacin leve de la clase "Pixel" de Colin Moock:
* http://moock.org/eas3/examples/moock_eas3_examples/eas3_bitmap_pixelclass/src/Pixel.as 
*/

package com.llops.utils
{
	public class PixelColorConverter 
	{
		private var value:uint;
		
		public function PixelColorConverter (n1:uint, n2:int=0, n3:int=0, n4:int=0) 
		{
			if (arguments.length == 1) {
				value = n1;
			} else {
				value = n1<<24 | n2<<16 | n3<<8 | n4;
			}
		}
		
		public function getValue():uint
		{
			return value;
		}

		public function setAlpha (n:int):void 
		{
			if (n < 0 || n > 255) {
				throw new RangeError("Supplied value must be in the range 0-255.");
			}
			value &= (0x00FFFFFF);
			value |= (n<<24);
		}

		public function setRed (n:int):void 
		{
			if (n < 0 || n > 255) {
				throw new RangeError("Supplied value must be in the range 0-255.");
			}
			value &= (0xFF00FFFF);
			value |= (n<<16);
		}

		public function setGreen (n:int):void 
		{
			if (n < 0 || n > 255) {
				throw new RangeError("Supplied value must be in the range 0-255.");
			}
			value &= (0xFFFF00FF);
			value |= (n<<8);
		}

		public function setBlue (n:int):void 
		{
			if (n < 0 || n > 255) {
				throw new RangeError("Supplied value must be in the range 0-255.");
			}
			value &= (0xFFFFFF00);
			value |= (n);
		}

		public function getAlpha ():int {
			return (value >> 24) & 0xFF;
		}

		public function getRed ():int {
			return (value >> 16) & 0xFF;
		}

		public function getGreen ():int {
			return (value >> 8) & 0xFF;
		}

		public function getBlue ():int {
			return value & 0xFF;
		}

		public function toStringHex():String 
		{
			var a:String = toStringAlpha();
			var r:String = toStringRed();
			var g:String = toStringGreen();
			var b:String = toStringBlue();
			
			if (a.length == 1) a = "0"+a;
			if (r.length == 1) r = "0"+r;
			if (g.length == 1) g = "0"+g;
			if (b.length == 1) b = "0"+b;
			
			var s:String = "0x"+a+r+g+b;
			return s;
		}

		public function toStringARGB (radix:int = 16):String 
		{
			var s:String = 
				"A:" + ((value >> 24)&0xFF).toString(radix).toUpperCase()
				+ " R:" + ((value >> 16)&0xFF).toString(radix).toUpperCase()
				+ " G:" + ((value >> 8)&0xFF).toString(radix).toUpperCase()
				+ " B:" + (value&0xFF).toString(radix).toUpperCase();
			return s;
		}

		public function toStringAlpha (radix:int = 16):String {
			var a:String = ((value >> 24)&0xFF).toString(radix).toUpperCase();
			return a;
		}

		public function toStringRed (radix:int = 16):String {
			return ((value >> 16)&0xFF).toString(radix).toUpperCase();
		}

		public function toStringGreen (radix:int = 16):String {
			return ((value >> 8)&0xFF).toString(radix).toUpperCase();
		}

		public function toStringBlue (radix:int = 16):String {
			return (value&0xFF).toString(radix).toUpperCase();
		}
	}
}